# LaTeX2HTML 2002-2-1 (1.71)
# Associate labels original text with physical files.


$key = q/half-cylinder/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/boundaries/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/refined1-cells/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/gfs2oogl/;
$external_labels{$key} = "$URL/" . q|node12.html|; 
$noresave{$key} = "$nosave";

$key = q/dx-screen/;
$external_labels{$key} = "$URL/" . q|node12.html|; 
$noresave{$key} = "$nosave";

$key = q/build_source/;
$external_labels{$key} = "$URL/" . q|node3.html|; 
$noresave{$key} = "$nosave";

$key = q/direction/;
$external_labels{$key} = "$URL/" . q|node7.html|; 
$noresave{$key} = "$nosave";

$key = q/gfsview/;
$external_labels{$key} = "$URL/" . q|node12.html|; 
$noresave{$key} = "$nosave";

$key = q/morebc/;
$external_labels{$key} = "$URL/" . q|node15.html|; 
$noresave{$key} = "$nosave";

$key = q/vorticity/;
$external_labels{$key} = "$URL/" . q|node8.html|; 
$noresave{$key} = "$nosave";

$key = q/build_darcs/;
$external_labels{$key} = "$URL/" . q|node3.html|; 
$noresave{$key} = "$nosave";

$key = q/refined1/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/refined2/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2002-2-1 (1.71)
# labels from external_latex_labels array.


$key = q/half-cylinder/;
$external_latex_labels{$key} = q|3|; 
$noresave{$key} = "$nosave";

$key = q/boundaries/;
$external_latex_labels{$key} = q|4|; 
$noresave{$key} = "$nosave";

$key = q/refined1-cells/;
$external_latex_labels{$key} = q|9|; 
$noresave{$key} = "$nosave";

$key = q/gfs2oogl/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/dx-screen/;
$external_latex_labels{$key} = q|7|; 
$noresave{$key} = "$nosave";

$key = q/build_source/;
$external_latex_labels{$key} = q|1.1.3|; 
$noresave{$key} = "$nosave";

$key = q/direction/;
$external_latex_labels{$key} = q|1|; 
$noresave{$key} = "$nosave";

$key = q/gfsview/;
$external_latex_labels{$key} = q|5|; 
$noresave{$key} = "$nosave";

$key = q/morebc/;
$external_latex_labels{$key} = q|4.1|; 
$noresave{$key} = "$nosave";

$key = q/vorticity/;
$external_latex_labels{$key} = q|2|; 
$noresave{$key} = "$nosave";

$key = q/build_darcs/;
$external_latex_labels{$key} = q|1.1.4|; 
$noresave{$key} = "$nosave";

$key = q/refined1/;
$external_latex_labels{$key} = q|8|; 
$noresave{$key} = "$nosave";

$key = q/refined2/;
$external_latex_labels{$key} = q|10|; 
$noresave{$key} = "$nosave";

1;

